## pyremotenode

__This is a port of the original pyremotenode prototyped for experiments at BAS,
which was designed for generic use but requires refactoring. Please note this 
refactor will rewrite significant portions of the code whilst this notice is in
place...__

The aim of this python module is to provide an easy manner by which to 
schedule, monitor and communicate via / with an SBC board of non-denominational 
 variety via a multitude of transport mediums (potentially, Iridium at present)...

### Development environment

This was designed for TS7400 use in 2018, so worked with Debian Wheezy and Python3.2-3.4

__This too is being changed__

### Version History

__Restarting, please refer to [changelog](CHANGELOG)__
